summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGiampaolo Rodola <g.rodola@gmail.com>2016-02-26 11:34:30 +0100
committerGiampaolo Rodola <g.rodola@gmail.com>2016-02-26 11:34:30 +0100
commit898c0d7fdd10e2d70f3627c6d50740b203f817d8 (patch)
tree698c29a0e3a77a84e714e7788bfd7dbc33e5f66c
parentd93a64d9662579b77cdd500da356470b166bd3d8 (diff)
downloadpysendfile-898c0d7fdd10e2d70f3627c6d50740b203f817d8.tar.gz
fix travis
-rwxr-xr-x.ci/travis/install.sh12
-rwxr-xr-x.ci/travis/run.sh2
2 files changed, 7 insertions, 7 deletions
diff --git a/.ci/travis/run.sh b/.ci/travis/run.sh
index 53f3088..eb92ee8 100755
--- a/.ci/travis/run.sh
+++ b/.ci/travis/run.sh
@@ -7,7 +7,7 @@ if [[ "$(uname -s)" == 'Darwin' ]]; then
if which pyenv > /dev/null; then
eval "$(pyenv init -)"
fi
- pyenv activate psutil
+ pyenv activate pysendfile
fi
python setup.py build
diff --git a/.ci/travis/install.sh b/.ci/travis/install.sh
index 29d0f77..0d21032 100755
--- a/.ci/travis/install.sh
+++ b/.ci/travis/install.sh
@@ -18,27 +18,27 @@ if [[ "$(uname -s)" == 'Darwin' ]]; then
case "${PYVER}" in
# py26)
# pyenv install 2.6.9
# pyenv virtualenv 2.6.9 psutil
# ;;
py27)
pyenv install 2.7.10
- pyenv virtualenv 2.7.10 psutil
+ pyenv virtualenv 2.7.10 pysendfile
;;
# py32)
# pyenv install 3.2.6
# pyenv virtualenv 3.2.6 psutil
# ;;
# py33)
# pyenv install 3.3.6
# pyenv virtualenv 3.3.6 psutil
# ;;
py34)
pyenv install 3.4.3
- pyenv virtualenv 3.4.3 psutil
+ pyenv virtualenv 3.4.3 pysendfile
;;
esac
pyenv rehash
- pyenv activate psutil
+ pyenv activate pysendfile
fi
if [[ $TRAVIS_PYTHON_VERSION == '2.5' ]]; then pip install unittest2; fi
@@ -18,27 +18,27 @@ if [[ "$(uname -s)" == 'Darwin' ]]; then
# py26)
# pyenv install 2.6.9
- # pyenv virtualenv 2.6.9 psutil
+ # pyenv virtualenv 2.6.9 pysendfile
# ;;
py27)
@@ -18,27 +18,27 @@ if [[ "$(uname -s)" == 'Darwin' ]]; then
# py32)
# pyenv install 3.2.6
- # pyenv virtualenv 3.2.6 psutil
+ # pyenv virtualenv 3.2.6 pysendfile
# ;;
# py33)
@@ -18,27 +18,27 @@ if [[ "$(uname -s)" == 'Darwin' ]]; then
# py33)
# pyenv install 3.3.6
- # pyenv virtualenv 3.3.6 psutil
+ # pyenv virtualenv 3.3.6 pysendfile
# ;;
py34)